@@ -1,6 +1,10 @@
+
+import sys
+import sys,os
+sys.path.append(os.getcwd())
 from gooey import Gooey, GooeyParser
-from .main_process import main_process
-from .comFuction import get_list
+from common.comFuction import get_list
+from main_flow.main_flow import main_process
 
 
 @Gooey(
@@ -55,3 +59,7 @@ def start_up_window():
     mp.run_all_process()
 
 
+
+if __name__ == '__main__':
+    start_up_window()
+
